@@ -244,7 +244,7 @@ pfm_read_dictionary (struct file_handle *h, struct pfm_read_info *inf)
 #endif
 
   /* Open the physical disk file. */
-  ext = (struct pfm_fhuser_ext *) R_alloc (1, sizeof(struct pfm_fhuser_ext));
+  ext = (struct pfm_fhuser_ext *) Calloc(1, struct pfm_fhuser_ext);
   ext->file = fopen (R_ExpandFileName(h->norm_fn), "rb");
   if (ext->file == NULL)
     {
